@@ -1,17 +1,22 @@
 import nonebot
 from nonebot.log import logger
-
-from .browser import get_browser, get_new_page, shutdown_browser
-from .data_source import (
-    md_to_pic,
-    html_to_pic,
-    text_to_pic,
-    capture_element,
-    template_to_pic,
-    template_to_html,
-)
 from nonebot.plugin import PluginMetadata
 
+from .browser import (
+    get_browser as get_browser,
+    get_new_page as get_new_page,
+    shutdown_browser as shutdown_browser,
+    init_browser as init_browser,
+)
+from .data_source import (
+    capture_element as capture_element,
+    html_to_pic as html_to_pic,
+    md_to_pic as md_to_pic,
+    template_to_html as template_to_html,
+    template_to_pic as template_to_pic,
+    text_to_pic as text_to_pic,
+)
+
 __plugin_meta__ = PluginMetadata(
     name="nonebot-plugin-htmlrender",
     description="通过浏览器渲染图片",
@@ -22,7 +27,6 @@ __plugin_meta__ = PluginMetadata(
 )
 
 driver = nonebot.get_driver()
-config = driver.config
 
 
 @driver.on_startup
@@ -32,9 +36,8 @@ async def init(**kwargs):
     Returns:
         Browser: Browser
     """
-    browser = await get_browser(**kwargs)
-    logger.info("Browser Started.")
-    return browser
+    logger.info("Browser Starting.")
+    return await init_browser(**kwargs)
 
 
 @driver.on_shutdown
@@ -45,13 +48,13 @@ async def shutdown():
 
 browser_init = init
 
-all = [
+__all__ = [
     "browser_init",
-    "text_to_pic",
+    "capture_element",
     "get_new_page",
+    "html_to_pic",
     "md_to_pic",
     "template_to_html",
     "template_to_pic",
-    "html_to_pic",
-    "capture_element",
+    "text_to_pic",
 ]
