@@ -1,6 +1,7 @@
 from typing import Optional
 
 from pydantic import BaseModel, Field
+from nonebot import get_driver, get_plugin_config
 
 
 class Config(BaseModel):
@@ -9,4 +10,8 @@ class Config(BaseModel):
     htmlrender_proxy_host: Optional[str] = Field(default=None)
     htmlrender_browser_channel: Optional[str] = Field(default=None)
     htmlrender_browser_executable_path: Optional[str] = Field(default=None)
-    htmlrender_connect_over_cdp: Optional[str] = Field(default=False)
+    htmlrender_connect_over_cdp: Optional[str] = Field(default=None)
+
+
+global_config = get_driver().config
+plugin_config = get_plugin_config(Config)
